@@ -109,9 +109,6 @@ void mp_chmap_fill_na(struct mp_chmap *map, int num);
 void mp_chmap_from_channels(struct mp_chmap *dst, int num_channels);
 void mp_chmap_set_unknown(struct mp_chmap *dst, int num_channels);
 
-void mp_chmap_remove_useless_channels(struct mp_chmap *map,
-                                      const struct mp_chmap *requested);
-
 uint64_t mp_chmap_to_lavc(const struct mp_chmap *src);
 uint64_t mp_chmap_to_lavc_unchecked(const struct mp_chmap *src);
 void mp_chmap_from_lavc(struct mp_chmap *dst, uint64_t src);
