@@ -57,7 +57,7 @@ static void reselect_streams(demuxer_t *demuxer)
     for (int n = 0; n < MPMIN(num_slave, p->num_streams); n++) {
         if (p->streams[n]) {
             demuxer_select_track(p->slave, demux_get_stream(p->slave, n),
-                demux_stream_is_selected(p->streams[n]));
+                MP_NOPTS_VALUE, demux_stream_is_selected(p->streams[n]));
         }
     }
 }
