@@ -22,8 +22,8 @@
 #include <unistd.h>
 #include <string.h>
 
+#include "options/m_config.h"
 #include "options/m_option.h"
-#include "options/options.h"
 
 #include "stream/stream.h"
 #include "demux.h"
@@ -129,7 +129,8 @@ struct priv {
 
 static int demux_rawaudio_open(demuxer_t *demuxer, enum demux_check check)
 {
-    struct demux_rawaudio_opts *opts = demuxer->opts->demux_rawaudio;
+    struct demux_rawaudio_opts *opts =
+        mp_get_config_group(demuxer, demuxer->global, &demux_rawaudio_conf);
 
     if (check != DEMUX_CHECK_REQUEST && check != DEMUX_CHECK_FORCE)
         return -1;
@@ -145,6 +146,9 @@ static int demux_rawaudio_open(demuxer_t *demuxer, enum demux_check check)
     c->force_channels = true;
     c->samplerate = opts->samplerate;
 
+    c->native_tb_num = 1;
+    c->native_tb_den = c->samplerate;
+
     int f = opts->aformat;
     // See PCM():               sign   float  bits    endian
     mp_set_pcm_codec(sh->codec, f & 1, f & 2, f >> 3, f & 4);
@@ -166,7 +170,8 @@ static int demux_rawaudio_open(demuxer_t *demuxer, enum demux_check check)
 
 static int demux_rawvideo_open(demuxer_t *demuxer, enum demux_check check)
 {
-    struct demux_rawvideo_opts *opts = demuxer->opts->demux_rawvideo;
+    struct demux_rawvideo_opts *opts =
+        mp_get_config_group(demuxer, demuxer->global, &demux_rawvideo_conf);
 
     if (check != DEMUX_CHECK_REQUEST && check != DEMUX_CHECK_FORCE)
         return -1;
@@ -233,6 +238,7 @@ static int demux_rawvideo_open(demuxer_t *demuxer, enum demux_check check)
     c->codec = decoder;
     c->codec_tag = imgfmt;
     c->fps = opts->fps;
+    c->reliable_fps = true;
     c->disp_w = width;
     c->disp_h = height;
     demux_add_sh_stream(demuxer, sh);
