@@ -93,7 +93,6 @@ static void switch_segment(struct demuxer *demuxer, struct segment *new,
                            double start_pts, int flags)
 {
     struct priv *p = demuxer->priv;
-    bool new_segment = p->current != new;
 
     if (!(flags & (SEEK_FORWARD | SEEK_BACKWARD)))
         flags |= SEEK_BACKWARD | SEEK_HR;
@@ -107,8 +106,7 @@ static void switch_segment(struct demuxer *demuxer, struct segment *new,
 
     for (int n = 0; n < p->num_streams; n++) {
         struct virtual_stream *vs = &p->streams[n];
-        if (new_segment)
-            vs->new_segment = true;
+        vs->new_segment = true;
         vs->eos_packets = 0;
     }
 
