@@ -99,9 +99,6 @@ enum mp_command_type {
     MP_CMD_VF,
     MP_CMD_VF_COMMAND,
 
-    /// Video output commands
-    MP_CMD_VO_CMDLINE,
-
     /// Internal for Lua scripts
     MP_CMD_SCRIPT_BINDING,
     MP_CMD_SCRIPT_MESSAGE,
@@ -117,6 +114,10 @@ enum mp_command_type {
 
     MP_CMD_RESCAN_EXTERNAL_FILES,
 
+    MP_CMD_APPLY_PROFILE,
+
+    MP_CMD_LOAD_SCRIPT,
+
     // Internal
     MP_CMD_COMMAND_LIST, // list of sub-commands in args[0].v.p
 };
