@@ -128,15 +128,11 @@ int m_config_parse(m_config_t *config, const char *location, bstr data,
         }
 
         int res;
-        if (profile) {
-            if (bstr_equals0(option, "profile-desc")) {
-                m_profile_set_desc(profile, value);
-                res = 0;
-            } else {
-                res = m_config_set_profile_option(config, profile, option, value);
-            }
+        if (bstr_equals0(option, "profile-desc")) {
+            m_profile_set_desc(profile, value);
+            res = 0;
         } else {
-            res = m_config_set_option_ext(config, option, value, flags);
+            res = m_config_set_profile_option(config, profile, option, value);
         }
         if (res < 0) {
             MP_ERR(config, "%s setting option %.*s='%.*s' failed.\n",
@@ -154,6 +150,8 @@ int m_config_parse(m_config_t *config, const char *location, bstr data,
         }
     }
 
+    m_config_finish_default_profile(config, flags);
+
     talloc_free(tmp);
     return 1;
 }
