@@ -25,6 +25,9 @@ typedef struct lavc_ctx {
     bool hwdec_failed;
     bool hwdec_notified;
 
+    // For HDR side-data caching
+    double cached_hdr_peak;
+
     struct mp_image **delay_queue;
     int num_delay_queue;
     int max_delay_queue;
