@@ -59,7 +59,6 @@ extern const vf_info_t vf_info_vaapi;
 extern const vf_info_t vf_info_vapoursynth;
 extern const vf_info_t vf_info_vapoursynth_lazy;
 extern const vf_info_t vf_info_vdpaupp;
-extern const vf_info_t vf_info_vdpaurb;
 extern const vf_info_t vf_info_buffer;
 extern const vf_info_t vf_info_d3d11vpp;
 
@@ -98,7 +97,6 @@ static const vf_info_t *const filter_list[] = {
 #endif
 #if HAVE_VDPAU
     &vf_info_vdpaupp,
-    &vf_info_vdpaurb,
 #endif
 #if HAVE_D3D_HWACCEL
     &vf_info_d3d11vpp,
