@@ -1,24 +1,24 @@
 /*
- * This file is part of MPlayer.
+ * This file is part of mpv.
  *
- * MPlayer is free software; you can redistribute it and/or modify
+ * mpv is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * MPlayer is distributed in the hope that it will be useful,
+ * mpv is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with MPlayer; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * with mpv.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <math.h>
 #include <inttypes.h>
 
 #include "common/msg.h"
@@ -47,11 +47,17 @@ static int lavfi_reconfig(struct vf_instance *vf,
     struct vf_priv_s *p = vf_lw_old_priv(vf);
     if (p->angle == 4) { // "auto"
         int r = in->rotate;
-        if (r < 0 || r >= 360 || (r % 90) != 0) {
+        if (r < 0 || r >= 360) {
             MP_ERR(vf, "Can't apply rotation of %d degrees.\n", r);
             return -1;
         }
-        vf_lw_update_graph(vf, NULL, "%s", rot[(r / 90) % 360]);
+        if (r % 90) {
+            double a = r / 180.0 * M_PI;
+            vf_lw_update_graph(vf, NULL, "rotate=%f:ow=rotw(%f):oh=roth(%f)",
+                               a, a, a);
+        } else {
+            vf_lw_update_graph(vf, NULL, "%s", rot[(r / 90) % 360]);
+        }
         out->rotate = 0;
     }
     return 0;
