@@ -8,6 +8,8 @@ struct mp_image_pool;
 struct mp_image_pool *mp_image_pool_new(int max_count);
 struct mp_image *mp_image_pool_get(struct mp_image_pool *pool, int fmt,
                                    int w, int h);
+// the reference to "new" is transferred to the pool
+void mp_image_pool_add(struct mp_image_pool *pool, struct mp_image *new);
 void mp_image_pool_clear(struct mp_image_pool *pool);
 
 void mp_image_pool_set_lru(struct mp_image_pool *pool);
