@@ -20,8 +20,6 @@
 
 @interface MpvEventsView : NSView <NSDraggingDestination>
 @property(nonatomic, retain) MpvCocoaAdapter *adapter;
-- (void)setFullScreen:(BOOL)willBeFullscreen;
-- (void)clear;
 - (BOOL)canHideCursor;
 - (void)signalMousePosition;
 @end
