@@ -160,18 +160,6 @@ const struct vo_driver video_out_image =
     .name = "image",
     .untimed = true,
     .priv_size = sizeof(struct priv),
-    .options = (const struct m_option[]) {
-        OPT_SUBOPT_LEGACY("jpeg-quality", "vo-image-jpeg-quality"),
-        OPT_SUBOPT_LEGACY("jpeg-smooth", "vo-image-jpeg-smooth"),
-        OPT_SUBOPT_LEGACY("jpeg-source-chroma", "vo-image-jpeg-source-chroma"),
-        OPT_SUBOPT_LEGACY("png-compression", "vo-image-png-compression"),
-        OPT_SUBOPT_LEGACY("png-filter", "vo-image-png-filter"),
-        OPT_SUBOPT_LEGACY("format", "vo-image-format"),
-        OPT_SUBOPT_LEGACY("high-bit-depth", "vo-image-high-bit-depth"),
-        OPT_SUBOPT_LEGACY("tag-colorspace", "vo-image-tag-colorspace"),
-        OPT_SUBOPT_LEGACY("outdir", "vo-image-outdir"),
-        {0},
-    },
     .preinit = preinit,
     .query_format = query_format,
     .reconfig = reconfig,
