@@ -37,7 +37,7 @@
 
 #include "x11_common.h"
 
-#if HAVE_SHM
+#if HAVE_SHM && HAVE_XEXT
 #include <sys/ipc.h>
 #include <sys/shm.h>
 #include <X11/extensions/XShm.h>
@@ -78,7 +78,7 @@ struct priv {
 
     int current_buf;
 
-#if HAVE_SHM
+#if HAVE_SHM && HAVE_XEXT
     int Shmem_Flag;
     XShmSegmentInfo Shminfo[2];
     int Shm_Warned_Slow;
@@ -420,8 +420,6 @@ static int control(struct vo *vo, uint32_t request, void *data)
 {
     struct priv *p = vo->priv;
     switch (request) {
-    case VOCTRL_GET_PANSCAN:
-        return VO_TRUE;
     case VOCTRL_SET_PANSCAN:
         if (vo->config_ok)
             resize(vo);
