@@ -82,12 +82,12 @@ void vo_calc_window_geometry(struct vo *vo, const struct mp_rect *screen,
     // The case of calling this function even though no video was configured
     // yet (i.e. vo->params==NULL) happens when vo_opengl creates a hidden
     // window in order to create an OpenGL context.
-    struct mp_image_params params = { .d_w = 320, .d_h = 200 };
+    struct mp_image_params params = { .w = 320, .h = 200 };
     if (vo->params)
         params = *vo->params;
 
-    int d_w = params.d_w;
-    int d_h = params.d_h;
+    int d_w, d_h;
+    mp_image_params_get_dsize(&params, &d_w, &d_h);
     if ((vo->driver->caps & VO_CAP_ROTATE90) && params.rotate % 180 == 90)
         MPSWAP(int, d_w, d_h);
     d_w = MPCLAMP(d_w * opts->window_scale, 1, 16000);
@@ -101,8 +101,8 @@ void vo_calc_window_geometry(struct vo *vo, const struct mp_rect *screen,
     calc_monitor_aspect(opts, scr_w, scr_h, &out_geo->monitor_par, &d_w, &d_h);
 
     apply_autofit(&d_w, &d_h, scr_w, scr_h, &opts->autofit, true, true);
-    apply_autofit(&d_w, &d_h, scr_w, scr_h, &opts->autofit_larger, false, true);
     apply_autofit(&d_w, &d_h, scr_w, scr_h, &opts->autofit_smaller, true, false);
+    apply_autofit(&d_w, &d_h, scr_w, scr_h, &opts->autofit_larger, false, true);
 
     out_geo->win.x0 = (int)(scr_w - d_w) / 2;
     out_geo->win.y0 = (int)(scr_h - d_h) / 2;
